@@ -1,7 +1,7 @@
 # -*- perl -*-
 
 #
-# $Id: FindPods.pm,v 5.10 2007/11/07 21:38:48 eserte Exp $
+# $Id: FindPods.pm,v 5.11 2008/02/03 16:10:51 eserte Exp $
 # Author: Slaven Rezic
 #
 # Copyright (C) 2001,2003,2004,2005,2007 Slaven Rezic. All rights reserved.
@@ -38,7 +38,7 @@ use vars qw($VERSION @EXPORT_OK $init_done %arch $arch_re);
 
 @EXPORT_OK = qw/%pods $has_cache pod_find/;
 
-$VERSION = sprintf("%d.%02d", q$Revision: 5.10 $ =~ /(\d+)\.(\d+)/);
+$VERSION = sprintf("%d.%02d", q$Revision: 5.11 $ =~ /(\d+)\.(\d+)/);
 
 BEGIN {  # Make a DEBUG constant very first thing...
   if(defined &DEBUG) {
@@ -273,15 +273,19 @@ sub simplify_name {
     } elsif ($^O =~ /^darwin/) {
 	$f =~ s|^pods/||; # ... and on MacOSX
     } elsif ($^O eq 'MSWin32') {
+	# oldstyle:
 	$f =~ s|^pod/perl|perl|i;
 	$f =~ s|^pod/Win32|Win32|i;
+	# newstyle:
+	$f =~ s|^pods/||;
     }
     $f;
 }
 
 sub type {
     local $_ = shift;
-    if    (/^perl/) { return "perl" }
+    if    (/^(?:perl|activeperl)/) { return "perl" }
+    elsif (/^a2p$/) { return "script" }
     elsif (/^[a-z]/ && !/^(mod_perl|lwpcook|lwptut|cgi_to_mod_perl|libapreq)/)
 	            { return "pragma" }
     else            { return "mod" }
